#[non_exhaustive]pub enum ResourceState {
StateUnknown,
StatePending,
StateProvisioning,
StateRunning,
StateSuspended,
StateDeleting,
UnknownValue(UnknownValue),
}Expand description
ResourceState describes the state the resource. A normal lifecycle of a new resource being created would be: PENDING -> PROVISIONING -> RUNNING. A normal lifecycle of an existing resource being deleted would be: RUNNING -> DELETING. Any failures during processing will result the resource to be in a SUSPENDED state.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
StateUnknown
Unspecified state.
StatePending
The resource is being prepared to be applied to the rack.
StateProvisioning
The resource has started being applied to the rack.
StateRunning
The resource has been pushed to the rack.
StateSuspended
The resource failed to push to the rack.
StateDeleting
The resource is under deletion.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using ResourceState::value or ResourceState::name.
Implementations