#[non_exhaustive]pub struct CreateSubnetRequest {
pub parent: String,
pub subnet_id: String,
pub subnet: Option<Subnet>,
pub request_id: String,
/* private fields */
}Expand description
Message for creating a Subnet
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. Value for parent.
subnet_id: StringRequired. Id of the requesting object If auto-generating Id server-side, remove this field and subnet_id from the method_signature of Create RPC
subnet: Option<Subnet>Required. The resource being created
request_id: StringOptional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
Implementations
Sourceimpl CreateSubnetRequest
impl CreateSubnetRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_subnet_id<T: Into<String>>(self, v: T) -> Self
pub fn set_subnet_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_subnet<T>(self, v: T) -> Self
pub fn set_subnet<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_subnet<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_subnet<T>(self, v: Option<T>) -> Self
Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = CreateSubnetRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for CreateSubnetRequest
impl Clone for CreateSubnetRequest
Sourcefn clone(&self) -> CreateSubnetRequest
fn clone(&self) -> CreateSubnetRequest
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more