Router

Struct Router 

#[non_exhaustive]
pub struct Router { pub name: String, pub create_time: Option<Timestamp>, pub update_time: Option<Timestamp>, pub labels: HashMap<String, String>, pub description: String, pub network: String, pub interface: Vec<Interface>, pub bgp_peer: Vec<BgpPeer>, pub bgp: Option<Bgp>, pub state: ResourceState, pub route_advertisements: Vec<String>, /* private fields */ }
Message describing Router object

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: String

Required. The canonical resource name of the router.

create_time: Option<Timestamp>

Output only. The time when the router was created.

update_time: Option<Timestamp>

Output only. The time when the router was last updated.

labels: HashMap<String, String>

Labels associated with this resource.

description: String

Optional. A free-text description of the resource. Max length 1024 characters.

network: String

Required. The canonical name of the network to which this router belongs. The name is in the form of projects/{project}/locations/{location}/zones/{zone}/networks/{network}.

interface: Vec<Interface>

Router interfaces.

bgp_peer: Vec<BgpPeer>

BGP peers.

bgp: Option<Bgp>

BGP information specific to this router.

state: ResourceState

Output only. Current stage of the resource to the device by config push.

route_advertisements: Vec<String>

Optional. A list of CIDRs in IP/Length format to advertise northbound as static routes from this router.

Implementations

Source

impl Router

pub fn new() -> Self

pub fn set_name<T: Into<String>>(self, v: T) -> Self

Sets the value of name.

Example
let x = Router::new().set_name("example");
pub fn set_create_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of create_time.

Example
use wkt::Timestamp;
let x = Router::new().set_create_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of create_time.

Example
use wkt::Timestamp;
let x = Router::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = Router::new().set_or_clear_create_time(None::<Timestamp>);
pub fn set_update_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of update_time.

Example
use wkt::Timestamp;
let x = Router::new().set_update_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of update_time.

Example
use wkt::Timestamp;
let x = Router::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = Router::new().set_or_clear_update_time(None::<Timestamp>);
pub fn set_labels<T, K, V>(self, v: T) -> Self
where T: IntoIterator<Item = (K, V)>, K: Into<String>, V: Into<String>,

Sets the value of labels.

Example
let x = Router::new().set_labels([
    ("key0", "abc"),
    ("key1", "xyz"),
]);
pub fn set_description<T: Into<String>>(self, v: T) -> Self

Sets the value of description.

Example
let x = Router::new().set_description("example");
pub fn set_network<T: Into<String>>(self, v: T) -> Self

Sets the value of network.

Example
let x = Router::new().set_network("example");
pub fn set_interface<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<Interface>,

Sets the value of interface.

Example
use google_cloud_edgenetwork_v1::model::router::Interface;
let x = Router::new()
    .set_interface([
        Interface::default()/* use setters */,
        Interface::default()/* use (different) setters */,
    ]);
pub fn set_bgp_peer<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<BgpPeer>,

Sets the value of bgp_peer.

Example
use google_cloud_edgenetwork_v1::model::router::BgpPeer;
let x = Router::new()
    .set_bgp_peer([
        BgpPeer::default()/* use setters */,
        BgpPeer::default()/* use (different) setters */,
    ]);
pub fn set_bgp<T>(self, v: T) -> Self
where T: Into<Bgp>,

Sets the value of bgp.

Example
use google_cloud_edgenetwork_v1::model::router::Bgp;
let x = Router::new().set_bgp(Bgp::default()/* use setters */);
pub fn set_or_clear_bgp<T>(self, v: Option<T>) -> Self
where T: Into<Bgp>,

Sets or clears the value of bgp.

Example
use google_cloud_edgenetwork_v1::model::router::Bgp;
let x = Router::new().set_or_clear_bgp(Some(Bgp::default()/* use setters */));
let x = Router::new().set_or_clear_bgp(None::<Bgp>);
pub fn set_state<T: Into<ResourceState>>(self, v: T) -> Self

Sets the value of state.

Example
use google_cloud_edgenetwork_v1::model::ResourceState;
let x0 = Router::new().set_state(ResourceState::StatePending);
let x1 = Router::new().set_state(ResourceState::StateProvisioning);
let x2 = Router::new().set_state(ResourceState::StateRunning);
pub fn set_route_advertisements<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of route_advertisements.

Example
let x = Router::new().set_route_advertisements(["a", "b", "c"]);